@@ -1,7 +1,7 @@
 package Devel::Chitin::OpTree::PMOP;
 use base 'Devel::Chitin::OpTree::LISTOP';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use B qw(PMf_CONTINUE PMf_ONCE PMf_GLOBAL PMf_MULTILINE PMf_KEEP PMf_SINGLELINE
          PMf_EXTENDED PMf_FOLD OPf_KIDS);
@@ -125,3 +125,28 @@ sub _match_flags {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Devel::Chitin::OpTree::PMOP - Deparser class for patten-matching OPs
+
+=head1 DESCRIPTION
+
+This package contains methods to deparse PMOPs (qr, match, etc)
+
+=head1 SEE ALSO
+
+L<Devel::Chitin::OpTree>, L<Devel::Chitin>, L<B>, L<B::Deparse>, L<B::DeparseTree>
+
+=head1 AUTHOR
+
+Anthony Brummett <brummett@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright 2016, Anthony Brummett.  This module is free software. It may
+be used, redistributed and/or modified under the same terms as Perl itself.
