@@ -1,7 +1,7 @@
 package Devel::Chitin::OpTree::UNOP;
 use base 'Devel::Chitin::OpTree';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use strict;
 use warnings;
@@ -62,7 +62,12 @@ sub pp_refgen {
     if ($anoncode) {
         my $subref = $self->_padval_sv($anoncode->op->targ);
         my $deparser = Devel::Chitin::OpTree->build_from_location($subref->object_2svref);
-        'sub { ' . $deparser->deparse . ' }';
+        my $deparsed = $deparser->deparse;
+        if ($deparsed =~ m/\n/) {
+            return join('', 'sub {', $self->_indent_block_text($deparsed), '}');
+        } else {
+            return join('', 'sub { ', $deparsed, ' }');
+        }
 
     } elsif ($first->is_null
              and $first->_ex_name eq 'pp_list'
@@ -521,3 +526,38 @@ foreach my $a ( [ pp_preinc     => '++',    1,  0 ],
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Devel::Chitin::OpTree::UNOP - Deparser class for unary OPs
+
+=head1 DESCRIPTION
+
+This package contains methods to deparse UNOPs (refgen, rv2sv, etc)
+
+=head2 Methods
+
+=over 4
+
+=item first
+
+Returns a L<Devel::Chitin::OpTree> instance for the child of this node
+
+=back
+
+=head1 SEE ALSO
+
+L<Devel::Chitin::OpTree>, L<Devel::Chitin>, L<B>, L<B::Deparse>, L<B::DeparseTree>
+
+=head1 AUTHOR
+
+Anthony Brummett <brummett@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright 2016, Anthony Brummett.  This module is free software. It may
+be used, redistributed and/or modified under the same terms as Perl itself.
