@@ -1,7 +1,7 @@
 package Devel::Chitin::OpTree::UNOP_AUX;
 use base 'Devel::Chitin::OpTree::UNOP';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use strict;
 use warnings;
@@ -77,3 +77,28 @@ sub pp_multideref {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Devel::Chitin::OpTree::UNOP_AUX - Deparser class for unary OPs with auxillary data
+
+=head1 DESCRIPTION
+
+This package contains methods to deparse UNOP_AUXs (multideref)
+
+=head1 SEE ALSO
+
+L<Devel::Chitin::OpTree>, L<Devel::Chitin>, L<B>, L<B::Deparse>, L<B::DeparseTree>
+
+=head1 AUTHOR
+
+Anthony Brummett <brummett@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright 2016, Anthony Brummett.  This module is free software. It may
+be used, redistributed and/or modified under the same terms as Perl itself.
